@@ -11,6 +11,7 @@ from django.utils.translation import ugettext_lazy as _
 from django.template.defaultfilters import slugify
 from django.utils.safestring import mark_safe
 from django.core.files.storage import default_storage
+from django.core.validators import email_re
 
 from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.payments.models import PaymentMethod
@@ -63,8 +64,8 @@ class FormForForm(forms.ModelForm):
             if "max_length" in arg_names:
                 field_args["max_length"] = FIELD_MAX_LENGTH
             if "choices" in arg_names:
-                choices = field.choices.split(",")
-                field_args["choices"] = zip(choices, choices)
+                field_args["choices"] = field.get_choices()
+                #field_args["choices"] = zip(choices, choices)
             if "initial" in arg_names:
                 default = field.default.lower()
                 if field_class == "BooleanField":
@@ -361,32 +362,51 @@ class FormForField(forms.ModelForm):
     class Meta:
         model = Field
         exclude = ["position"]
-    
-    def clean_function_params(self):
-        function_params = self.cleaned_data['function_params']
-        clean_params = ''
-        for val in function_params.split(','):
-            clean_params = val.strip() + ',' + clean_params
-        return clean_params[0:len(clean_params)-1]
         
     def clean(self):
         cleaned_data = self.cleaned_data
         field_function = cleaned_data.get("field_function")
-        function_params = cleaned_data.get("function_params")
+        choices = cleaned_data.get("choices")
         field_type = cleaned_data.get("field_type")
         required = cleaned_data.get("required")
         
         if field_function == "GroupSubscription":
             if field_type != "BooleanField":
                 raise forms.ValidationError("This field's function requires Checkbox as a field type")
-            if not function_params:
+            if not choices:
                 raise forms.ValidationError("This field's function requires at least 1 group specified.")
             else:
-                for val in function_params.split(','):
+                for val in choices.split(','):
                     try:
-                        Group.objects.get(name=val)
+                        Group.objects.get(name=val.strip())
                     except Group.DoesNotExist:
                         raise forms.ValidationError("The group \"%s\" does not exist" % (val))
+
+        if field_function == "Recipients":
+            if (field_type != "MultipleChoiceField/django.forms.CheckboxSelectMultiple" and 
+                field_type != "MultipleChoiceField" and
+                field_type != "BooleanField" and
+                field_type != "ChoiceField"):
+                raise forms.ValidationError("The \"Email to Recipients\" function requires Multi-select - Checkboxes "
+                                            + "or Multi-select - Select Many as field type")
+
+            if field_type == "BooleanField":
+                if not choices:
+                    raise forms.ValidationError("The \"Email to Recipients\" function requires at least 1 email specified.")
+                else:
+                    for val in choices.split(','):
+                        if not email_re.match(val.strip()):
+                            raise forms.ValidationError("\"%s\" is not a valid email address" % (val))
+            else:
+                if not choices:
+                    raise forms.ValidationError("The \"Email to Recipients\" function requires at least 1 choice specified.")
+                else:
+                    for val in choices.split(','):
+                        val = val.split(':')
+                        if len(val) < 2:
+                            raise forms.ValidationError("The \"Email to Recipients\" function requires choices to be in the following format: <choice_label>:<email_address>.")
+                        if not email_re.match(val[1].strip()):
+                            raise forms.ValidationError("\"%s\" is not a valid email address" % (val[1]))
                     
         if field_function != None and field_function.startswith("Email"):
             if field_type != "CharField":
